# Examples for CacheDiT  

## Install requirements  

```bash
pip3 install -r requirements.txt
```

## Run examples  

- FLUX.1-dev 

```bash
python3 run_flux.py
```

- FLUX.1-Fill-dev 

```bash
python3 run_flux_fill.py
```

- CogVideoX 

```bash
python3 run_cogvideox.py
```

- Wan2.1 

```bash
python3 run_wan.py
```

- Mochi

```bash
python3 run_mochi.py
```

- HunyuanVideo

```bash
python3 run_hunyuan_video.py
```
